![logo](https://raw.githubusercontent.com/cybergarage/uecho-py/main/doc/img/logo.png?token=AAEPHD4KEMD7MIIGJNOQPX3BR7O4M)

[![pytest](https://github.com/cybergarage/uecho-py/actions/workflows/pytest.yml/badge.svg)](https://github.com/cybergarage/uecho-py/actions/workflows/pytest.yml)

The `uecho-py` is a portable and cross platform development framework for creating controller applications and devices of [ECHONET Lite][enet] for Python developers. [ECHONET][enet] is an open standard specification for IoT devices in Japan, it specifies more than 100 IoT devices such as crime prevention sensor, air conditioner and refrigerator.

[enet]:http://echonet.jp/english/
